# <center>Gabriel<center>

![Gabriel](assets/downloadaaaa.jpg "Gabriel")

Gabriel is a Discord RPC cli tool

# Usage

Config:
```bash
gab --config <config file>.json
```

To see options/how to do it without a preset config (not recommended, messy):
```
gab --help
```
or
```
gab -h
```

# Installation
Coming soon

# FAQ

>How do I install it?

Coming soon

>Why did you make this?

This is the only discord rpc cli tool I know at the moment